import { scaleBand, scaleLinear, max } from 'd3';
import { BarMarks } from './Marks';
import { AxisLeft } from './AxisLeft';
import { AxisBottom } from '../AxisBottom';

const xAxisLabelOffset = 30;
const yAxisLabelOffset = 50;

export const BarColorMark = ({
  data, 
  xValue, 
  yValue, 
  innerWidth, 
  innerHeight,
  xAxisLabel,
  xAxisTickFormat
}) => {
  console.log('Calling BarColorMark...');

  const yBarScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .paddingInner(0.15);

  //This is for max, we should do sth different!
  const xBarScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  // console.log(xValue);
  // console.log(yValue);
  // console.log(data.map(yValue));
  // console.log(max(data, xValue));
  
  return (
    <>
      <AxisBottom
        xScale={xBarScale}
        innerHeight={innerHeight}
        tickFormat={xAxisTickFormat}
      />
      <AxisLeft yScale={yBarScale} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
      </text>
      <BarMarks
        data={data}
        xScale={xBarScale}
        yScale={yBarScale}
        xValue={xValue}
        yValue={yValue}
        tooltipFormat={xAxisTickFormat}
      />
    </>
   );
};
